colour.utilities — Colour 0.3.0 documentation

# Source code for colour.utilities

    #!/usr/bin/env python
    # -*- coding: utf-8 -*-

    from __future__ import absolute_import

    from .common import is_scipy_installed, is_string
    from .data_structures import Lookup, Structure, CaseInsensitiveMapping
    from .verbose import warning

    __all__ = ['is_scipy_installed', 'is_string']
    __all__ += ['Lookup', 'Structure', 'CaseInsensitiveMapping']
    __all__ += ['warning']